@@ -1,6 +1,6 @@
 package Dist::Zilla::PluginBundle::YANICK;
 our $AUTHORITY = 'cpan:YANICK';
-$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.25.1';
+$Dist::Zilla::PluginBundle::YANICK::VERSION = '0.26.0';
 # ABSTRACT: Be like Yanick when you build your dists
 
 # [TODO] add CONTRIBUTING file
@@ -62,9 +62,8 @@ sub configure {
             issues => 1,
         } ],
         qw/ MetaYAML MetaJSON PodWeaver License
-          ReadmeFromPod 
-          ReadmeMarkdownFromPod
           /,
+        [ ReadmeAnyFromPod => { type => 'gfm', filename => 'README.mkdn' } ],
         [ CoderwallEndorse => { users => 'yanick:Yanick' } ],
         [ NextRelease => { 
                 time_zone => 'America/Montreal',
@@ -144,7 +143,6 @@ sub configure {
     qw/
         SchwartzRatio 
         Test::UnusedVars
-        Test::PAUSE::Permissions
         RunExtraTests
     /
     );
@@ -184,7 +182,7 @@ Dist::Zilla::PluginBundle::YANICK - Be like Yanick when you build your dists
 
 =head1 VERSION
 
-version 0.25.1
+version 0.26.0
 
 =head1 DESCRIPTION
 
@@ -214,7 +212,6 @@ his distributions. It's roughly equivalent to
     [License]
     [HelpWanted]
 
-    [ReadmeFromPod]
     [ReadmeMarkdownFromPod]
 
     [CoderwallEndorse]
@@ -275,7 +272,6 @@ his distributions. It's roughly equivalent to
 
     [RunExtraTests]
     [Test::UnusedVars]
-    [Test::PAUSE::Permissions]
 
     [DOAP]
     process_changes = 1
